@@ -35,6 +35,7 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
     let padding = 150.0;
     let paddingy = 100.0;
 
+    /*
     writer.single("rect", |d| {
         d.attr("class", "poloto_background")
             .attr("fill", "white")
@@ -43,6 +44,7 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
             .attr("width", width)
             .attr("height", height);
     });
+    */
 
     //Find range.
     let [minx, maxx, miny, maxy] = util::find_bounds(
@@ -93,12 +95,15 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
             PlotType::Line => {
                 if name_exists {
                     writer.single("line", |d| {
-                        d.attr("class", format_args!("poloto{}stroke", colori))
-                            .attr("stroke", "black")
-                            .attr("x1", legendx1)
-                            .attr("x2", legendx1 + padding / 3.0)
-                            .attr("y1", legendy1)
-                            .attr("y2", legendy1);
+                        d.attr(
+                            "class",
+                            format_args!("poloto{}stroke poloto{}legend", colori, colori),
+                        )
+                        .attr("stroke", "black")
+                        .attr("x1", legendx1)
+                        .attr("x2", legendx1 + padding / 3.0)
+                        .attr("y1", legendy1)
+                        .attr("y2", legendy1);
                     });
                 }
 
@@ -114,21 +119,16 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
             PlotType::Scatter => {
                 if name_exists {
                     writer.single("line", |d| {
-                        d.attr("class", format_args!("scatter poloto{}stroke", colori))
-                            .attr("stroke", "black")
-                            .attr("x1", legendx1 + padding / 30.0)
-                            .attr("x2", legendx1 + padding / 30.0)
-                            .attr("y1", legendy1)
-                            .attr("y2", legendy1);
+                        d.attr(
+                            "class",
+                            format_args!("scatter poloto{}stroke poloto{}legend", colori, colori),
+                        )
+                        .attr("stroke", "black")
+                        .attr("x1", legendx1 + padding / 30.0)
+                        .attr("x2", legendx1 + padding / 30.0)
+                        .attr("y1", legendy1)
+                        .attr("y2", legendy1);
                     });
-                    /*
-                    writer.single("circle", |d| {
-                        d.attr("class", format_args!("poloto{}fill", colori))
-                            .attr("cx", legendx1 + padding / 30.0)
-                            .attr("cy", legendy1)
-                            .attr("r", padding / 30.0);
-                    });
-                    */
                 }
 
                 writer.single("path", |d| {
@@ -145,13 +145,16 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
             PlotType::Histo => {
                 if name_exists {
                     writer.single("rect", |d| {
-                        d.attr("class", format_args!("poloto{}fill", colori))
-                            .attr("x", legendx1)
-                            .attr("y", legendy1 - padding / 30.0)
-                            .attr("width", padding / 3.0)
-                            .attr("height", padding / 20.0)
-                            .attr("rx", padding / 30.0)
-                            .attr("ry", padding / 30.0);
+                        d.attr(
+                            "class",
+                            format_args!("poloto{}fill poloto{}legend", colori, colori),
+                        )
+                        .attr("x", legendx1)
+                        .attr("y", legendy1 - padding / 30.0)
+                        .attr("width", padding / 3.0)
+                        .attr("height", padding / 20.0)
+                        .attr("rx", padding / 30.0)
+                        .attr("ry", padding / 30.0);
                     });
                 }
 
@@ -181,13 +184,16 @@ pub fn render<T: std::fmt::Write>(plotter: &mut Plotter, writer: T) -> T {
             PlotType::LineFill => {
                 if name_exists {
                     writer.single("rect", |d| {
-                        d.attr("class", format_args!("poloto{}fill", colori))
-                            .attr("x", legendx1)
-                            .attr("y", legendy1 - padding / 30.0)
-                            .attr("width", padding / 3.0)
-                            .attr("height", padding / 20.0)
-                            .attr("rx", padding / 30.0)
-                            .attr("ry", padding / 30.0);
+                        d.attr(
+                            "class",
+                            format_args!("poloto{}fill poloto{}legend", colori, colori),
+                        )
+                        .attr("x", legendx1)
+                        .attr("y", legendy1 - padding / 30.0)
+                        .attr("width", padding / 3.0)
+                        .attr("height", padding / 20.0)
+                        .attr("rx", padding / 30.0)
+                        .attr("ry", padding / 30.0);
                     });
                 }
 
